""" This package provides support for writing plugins for Spyke Viewer.
It belongs to `spykeutils` so that plugins can be executed in an evironment
where the `spykeviewer` package and its dependencies are not installed
(e.g. servers).

:mod:`analysis_plugin` Module
-----------------------------

.. automodule:: spykeutils.plugin.analysis_plugin
    :members:
    :show-inheritance:

:mod:`data_provider` Module
---------------------------

.. automodule:: spykeutils.plugin.data_provider
    :members:
    :show-inheritance:

:mod:`gui_data` Module
----------------------

.. automodule:: spykeutils.plugin.gui_data
"""